==> open-xchange-messaging-facebook_6.16.1.0.orig.tar.gz: open-xchange-messaging-facebook-6.16.1.0/src/com/openexchange/messaging/facebook/osgi/FacebookMessagingActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.facebook.osgi;

import static com.openexchange.messaging.facebook.services.FacebookMessagingServiceRegistry.getServiceRegistry;
import java.util.ArrayList;
import java.util.Dictionary;
import java.util.Hashtable;
import java.util.List;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.event.EventConstants;
import org.osgi.service.event.EventHandler;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.config.ConfigurationService;
import com.openexchange.context.ContextService;
import com.openexchange.exceptions.osgi.ComponentRegistration;
import com.openexchange.messaging.MessagingService;
import com.openexchange.messaging.facebook.FacebookConfiguration;
import com.openexchange.messaging.facebook.FacebookConstants;
import com.openexchange.messaging.facebook.FacebookMessagingException;
import com.openexchange.messaging.facebook.FacebookMessagingService;
import com.openexchange.messaging.facebook.exception.FacebookMessagingExceptionFactory;
import com.openexchange.messaging.facebook.session.FacebookEventHandler;
import com.openexchange.messaging.facebook.session.FacebookSessionRenewalTask;
import com.openexchange.server.osgiservice.DeferredActivator;
import com.openexchange.server.osgiservice.ServiceRegistry;
import com.openexchange.sessiond.SessiondEventConstants;
import com.openexchange.sessiond.SessiondService;
import com.openexchange.timer.ScheduledTimerTask;
import com.openexchange.timer.TimerService;
import com.openexchange.user.UserService;

/**
 * {@link FacebookMessagingActivator}
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class FacebookMessagingActivator extends DeferredActivator {

    private List<ServiceTracker> trackers;

    private List<ServiceRegistration> registrations;

    private ComponentRegistration componentRegistration;

    private ScheduledTimerTask scheduledTimerTask;

    /**
     * Initializes a new {@link FacebookMessagingActivator}.
     */
    public FacebookMessagingActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] {
            ConfigurationService.class, ContextService.class, UserService.class, SessiondService.class, TimerService.class };
    }

    @Override
    protected void handleAvailability(final Class<?> clazz) {
        final org.apache.commons.logging.Log logger = org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class);
        if (logger.isInfoEnabled()) {
            logger.info("Re-available service: " + clazz.getName());
        }
        final Object service = getService(clazz);
        getServiceRegistry().addService(clazz, service);
        if (TimerService.class.equals(clazz)) {
            scheduleTimerTask((TimerService) service);
        }
    }

    @Override
    protected void handleUnavailability(final Class<?> clazz) {
        final org.apache.commons.logging.Log logger = org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class);
        if (logger.isWarnEnabled()) {
            logger.warn("Absent service: " + clazz.getName());
        }
        if (TimerService.class.equals(clazz)) {
            dropTimerTask((TimerService) getService(clazz));
        }
        getServiceRegistry().removeService(clazz);
    }

    @Override
    protected void startBundle() throws Exception {
        try {
            /*
             * (Re-)Initialize service registry with available services
             */
            {
                final ServiceRegistry registry = getServiceRegistry();
                registry.clearRegistry();
                final Class<?>[] classes = getNeededServices();
                for (int i = 0; i < classes.length; i++) {
                    final Object service = getService(classes[i]);
                    if (null != service) {
                        registry.addService(classes[i], service);
                    }
                }
            }
            /*
             * Some init stuff
             */
            FacebookConstants.init();
            FacebookConfiguration.getInstance().configure(getService(ConfigurationService.class));
            /*
             * Register component
             */
            componentRegistration =
                new ComponentRegistration(
                    context,
                    FacebookMessagingException.FACEBOOK_COMPONENT,
                    "com.openexchange.messaging.facebook",
                    FacebookMessagingExceptionFactory.getInstance());

            trackers = new ArrayList<ServiceTracker>();
            for (final ServiceTracker tracker : trackers) {
                tracker.open();
            }
            /*
             * Register services
             */
            registrations = new ArrayList<ServiceRegistration>(2);
            registrations.add(context.registerService(MessagingService.class.getName(), new FacebookMessagingService(), null));
            /*
             * Register event handler to detect removed sessions
             */
            final Dictionary<Object, Object> serviceProperties = new Hashtable<Object, Object>(1);
            serviceProperties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.getAllTopics());
            registrations.add(context.registerService(EventHandler.class.getName(), new FacebookEventHandler(), serviceProperties));
            /*
             * Schedule timer task
             */
            scheduleTimerTask(getService(TimerService.class));

            try {
                // new StartUpTest().test();
            } catch (final Exception e) {
                org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class).error(e.getMessage(), e);
            }

        } catch (final Exception e) {
            org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class).error(e.getMessage(), e);
            throw e;
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        try {
            /*
             * Drop scheduled timer task
             */
            dropTimerTask(getService(TimerService.class));
            /*
             * Unregister component
             */
            if (null != componentRegistration) {
                componentRegistration.unregister();
                componentRegistration = null;
            }
            if (null != trackers) {
                while (!trackers.isEmpty()) {
                    trackers.remove(0).close();
                }
                trackers = null;
            }
            if (null != registrations) {
                while (!registrations.isEmpty()) {
                    registrations.remove(0).unregister();
                }
                registrations = null;
            }

            FacebookConstants.drop();
            FacebookConfiguration.getInstance().drop();

            /*
             * Clear service registry
             */
            getServiceRegistry().clearRegistry();
        } catch (final Exception e) {
            org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class).error(e.getMessage(), e);
            throw e;
        }
    }

    /**
     * Schedules timer task
     * 
     * @param timerService The timer service
     */
    private void scheduleTimerTask(final TimerService timerService) {
        if (null != timerService) {
            /*
             * Drop previous if present
             */
            dropTimerTask(timerService);
            /*
             * Schedule new one
             */
            final ConfigurationService configurationService = getService(ConfigurationService.class);
            scheduledTimerTask =
                timerService.scheduleWithFixedDelay(
                    new FacebookSessionRenewalTask(),
                    1000,
                    null == configurationService ? 300000 : configurationService.getIntProperty(
                        "com.openexchange.messaging.facebook.renewalFrequence",
                        300000));
        }
    }

    /**
     * Drops scheduled timer task
     */
    private void dropTimerTask(final TimerService timerService) {
        if (null != scheduledTimerTask) {
            scheduledTimerTask.cancel();
            scheduledTimerTask = null;
            if (null != timerService) {
                timerService.purge();
            }
        }
    }

}

==> open-xchange-messaging-facebook_6.20.8.0.orig.tar.gz: open-xchange-messaging-facebook-6.20.8.0/src/com/openexchange/messaging/facebook/osgi/FacebookMessagingActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.facebook.osgi;

import static com.openexchange.messaging.facebook.services.FacebookMessagingServiceRegistry.getServiceRegistry;
import java.util.ArrayList;
import java.util.Dictionary;
import java.util.Hashtable;
import java.util.List;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.event.EventConstants;
import org.osgi.service.event.EventHandler;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.config.ConfigurationService;
import com.openexchange.context.ContextService;
import com.openexchange.exceptions.osgi.ComponentRegistration;
import com.openexchange.html.HTMLService;
import com.openexchange.i18n.I18nService;
import com.openexchange.messaging.MessagingService;
import com.openexchange.messaging.facebook.FacebookConfiguration;
import com.openexchange.messaging.facebook.FacebookConstants;
import com.openexchange.messaging.facebook.FacebookMessagingException;
import com.openexchange.messaging.facebook.FacebookMessagingService;
import com.openexchange.messaging.facebook.FacebookOAuthAccountDeleteListener;
import com.openexchange.messaging.facebook.exception.FacebookMessagingExceptionFactory;
import com.openexchange.messaging.facebook.session.FacebookEventHandler;
import com.openexchange.oauth.OAuthAccountDeleteListener;
import com.openexchange.oauth.OAuthAccountInvalidationListener;
import com.openexchange.oauth.OAuthService;
import com.openexchange.secret.SecretService;
import com.openexchange.secret.osgi.tools.WhiteboardSecretService;
import com.openexchange.server.osgiservice.DeferredActivator;
import com.openexchange.server.osgiservice.ServiceRegistry;
import com.openexchange.sessiond.SessiondEventConstants;
import com.openexchange.sessiond.SessiondService;
import com.openexchange.user.UserService;

/**
 * {@link FacebookMessagingActivator}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class FacebookMessagingActivator extends DeferredActivator {

    private List<ServiceTracker> trackers;

    private List<ServiceRegistration> registrations;

    private ComponentRegistration componentRegistration;

    private WhiteboardSecretService secretService;

    /**
     * Initializes a new {@link FacebookMessagingActivator}.
     */
    public FacebookMessagingActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] {
            ConfigurationService.class, ContextService.class, UserService.class, SessiondService.class, HTMLService.class, OAuthService.class, SecretService.class};
    }

    @Override
    protected void handleAvailability(final Class<?> clazz) {
        final org.apache.commons.logging.Log logger = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class));
        if (logger.isInfoEnabled()) {
            logger.info("Re-available service: " + clazz.getName());
        }
        final Object service = getService(clazz);
        getServiceRegistry().addService(clazz, service);
    }

    @Override
    protected void handleUnavailability(final Class<?> clazz) {
        final org.apache.commons.logging.Log logger = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class));
        if (logger.isWarnEnabled()) {
            logger.warn("Absent service: " + clazz.getName());
        }
        getServiceRegistry().removeService(clazz);
    }

    @Override
    protected void startBundle() throws Exception {
        try {
            /*
             * (Re-)Initialize service registry with available services
             */
            {
                final ServiceRegistry registry = getServiceRegistry();
                registry.clearRegistry();
                final Class<?>[] classes = getNeededServices();
                for (final Class<?> classe : classes) {
                    final Object service = getService(classe);
                    if (null != service) {
                        registry.addService(classe, service);
                    }
                }

                secretService = new WhiteboardSecretService(context);
                secretService.open();
                registry.addService(SecretService.class, secretService);
            }


            /*
             * Some init stuff
             */
            FacebookConstants.init();
            FacebookConfiguration.getInstance().configure(getService(ConfigurationService.class));
            /*
             * Register component
             */
            componentRegistration =
                new ComponentRegistration(
                    context,
                    FacebookMessagingException.FACEBOOK_COMPONENT,
                    "com.openexchange.messaging.facebook",
                    FacebookMessagingExceptionFactory.getInstance());

            trackers = new ArrayList<ServiceTracker>(1);
            trackers.add(new ServiceTracker(context, I18nService.class.getName(), new I18nCustomizer(context)));
            for (final ServiceTracker tracker : trackers) {
                tracker.open();
            }
            /*
             * Register services
             */
            registrations = new ArrayList<ServiceRegistration>(2);
            registrations.add(context.registerService(MessagingService.class.getName(), new FacebookMessagingService(), null));
            /*
             * Register event handler to detect removed sessions
             */
            final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
            serviceProperties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.getAllTopics());
            registrations.add(context.registerService(EventHandler.class.getName(), new FacebookEventHandler(), serviceProperties));
            registrations.add(context.registerService(OAuthAccountDeleteListener.class.getName(), new FacebookOAuthAccountDeleteListener(), null));
            registrations.add(context.registerService(OAuthAccountInvalidationListener.class.getName(), new FacebookOAuthAccountDeleteListener(), null));
            
            try {
                // new StartUpTest().test();
            } catch (final Exception e) {
                com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class)).error(e.getMessage(), e);
            }

        } catch (final Exception e) {
            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class)).error(e.getMessage(), e);
            throw e;
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        try {
            if(secretService != null) {
                secretService.close();
            }
            /*
             * Unregister component
             */
            if (null != componentRegistration) {
                componentRegistration.unregister();
                componentRegistration = null;
            }
            if (null != trackers) {
                while (!trackers.isEmpty()) {
                    trackers.remove(0).close();
                }
                trackers = null;
            }
            if (null != registrations) {
                while (!registrations.isEmpty()) {
                    registrations.remove(0).unregister();
                }
                registrations = null;
            }

            FacebookConstants.drop();
            FacebookConfiguration.getInstance().drop();

            /*
             * Clear service registry
             */
            getServiceRegistry().clearRegistry();
        } catch (final Exception e) {
            com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(FacebookMessagingActivator.class)).error(e.getMessage(), e);
            throw e;
        }
    }

}
